@@ -18,7 +18,7 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 =end
 
 # Feed2Imap version
-F2I_VERSION = '0.9.2'
+F2I_VERSION = '0.9.3'
 
 require 'feed2imap/config'
 require 'feed2imap/cache'
@@ -121,16 +121,32 @@ class Feed2Imap
             if feed.url
               s = HTTPFetcher::fetch(feed.url, @cache.get_last_check(feed.name))
             elsif feed.execurl
+              # avoid running more than one command at the same time.
+              # We need it because the called command might not be
+              # thread-safe, and we need to get the right exitcode
+              mutex.lock
               s = %x{#{feed.execurl}}
+              if $?.exitstatus != 0
+                @logger.warn("Command for #{feed.name} exited with status #{$?.exitstatus} !")
+              end
+              mutex.unlock
             else
               @logger.warn("No way to fetch feed #{feed.name} !")
             end
             if feed.filter
+              # avoid running more than one command at the same time.
+              # We need it because the called command might not be
+              # thread-safe, and we need to get the right exitcode.
+              mutex.lock
               Open3::popen3(feed.filter) do |stdin, stdout|
                 stdin.puts s
                 stdin.close
                 s = stdout.read
               end
+              if $?.exitstatus != 0
+                @logger.warn("Filter command for #{feed.name} exited with status #{$?.exitstatus}. Output might be corrupted !")
+              end
+              mutex.unlock
             end
             sparefetchers_mutex.synchronize do
               sparefetchers += 1
@@ -214,13 +230,13 @@ class Feed2Imap
       begin
         if !cacherebuild
           updateditems.each do |i|
-            email = item_to_mail(i, i.cacheditem.index, true, f.name)
+            email = item_to_mail(i, i.cacheditem.index, true, f.name, f.include_images, f.wrapto)
             f.imapaccount.updatemail(f.folder, email,
                                      i.cacheditem.index, i.date || Time::new)
           end
           # reverse is needed to upload older items first (fixes gna#8986)
           newitems.reverse.each do |i|
-            email = item_to_mail(i, i.cacheditem.index, false, f.name)
+            email = item_to_mail(i, i.cacheditem.index, false, f.name, f.include_images, f.wrapto)
             f.imapaccount.putmail(f.folder, email, i.date || Time::new)
           end
         end
