@@ -26,7 +26,8 @@ require 'feedparser'
 require 'feedparser/text-output'
 require 'feedparser/html-output'
 require 'base64'
-require 'feed2imap/rubymail_patch'
+require 'rmail'
+require 'digest/md5'
 
 class String
   def needMIME
@@ -46,7 +47,7 @@ class String
   end
 end
 
-def item_to_mail(item, index, updated, from = 'Feed2Imap')
+def item_to_mail(item, index, updated, from = 'Feed2Imap', inline_images = false, wrapto = false)
   message = RMail::Message::new
   if item.creator and item.creator != ''
     if item.creator.include?('@')
@@ -76,15 +77,51 @@ def item_to_mail(item, index, updated, from = 'Feed2Imap')
     end
   end
   textpart = RMail::Message::new
-  textpart.header['Content-Type'] = 'text/plain; charset=utf-8'
+  textpart.header['Content-Type'] = 'text/plain; charset=utf-8; format=flowed'
   textpart.header['Content-Transfer-Encoding'] = '8bit'
-  textpart.body = item.to_text
+  textpart.body = item.to_text(true, wrapto)
   htmlpart = RMail::Message::new
   htmlpart.header['Content-Type'] = 'text/html; charset=utf-8'
   htmlpart.header['Content-Transfer-Encoding'] = '8bit'
   htmlpart.body = item.to_html
-  message.add_part(textpart)
-  message.add_part(htmlpart)
+
+  # inline images as attachments
+  if inline_images
+    message.header.set('Content-Type', 'multipart/related', 'type'=> 'multipart/alternative')
+    texthtml = RMail::Message::new
+    texthtml.header.set('Content-Type', 'multipart/alternative')
+    texthtml.add_part(textpart)
+    texthtml.add_part(htmlpart)
+    message.add_part(texthtml)
+
+    htmlpart.body.gsub!(/(<img[^>]+)src="(\S+?\/([^\/]+?\.(png|gif|jpe?g)))"([^>]*>)/i) do |match|
+      # $2 contains url, $3 the image name, $4 the image extension
+      begin
+        image = Base64.encode64(HTTPFetcher::fetch($2, Time.at(0)).chomp) + "\n"
+        cid = "#{Digest::MD5.hexdigest($2)}@feed2imap.acme.com"
+        imgpart = RMail::Message.new
+        imgpart.header.set('Content-ID', "<#{cid}>")
+        type = $4
+        type = 'jpeg' if type.downcase == 'jpg' # hack hack hack
+        imgpart.header.set('Content-Type', "image/#{type}", 'name' => $3)
+        imgpart.header.set('Content-Disposition', 'attachment', 'filename' => $3)
+        imgpart.header.set('Content-Transfer-Encoding', 'base64')
+        imgpart.body = image
+        message.add_part(imgpart)
+        # now to specify what to replace with
+        newtag = "#{$1}src=\"cid:#{cid}\"#{$5}"
+        #print "#{cid}: Replacing '#{$&}' with '#{newtag}'...\n"
+        newtag
+      rescue
+        #print "Error while fetching image #{$2}: #{$!}...\n"
+        $& # don't modify on exception
+      end
+    end
+  else
+    message.header['Content-Type'] = 'multipart/alternative'
+    message.add_part(textpart)
+    message.add_part(htmlpart)
+  end
   return message.to_s
 end
 
